/*! readable-code v3.4.15 by Sebastian Software <s.werner@sebastian-software.de> */
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var gulp = _interopDefault(require('gulp'));
var spawn = _interopDefault(require('cross-spawn'));
var stylelint = _interopDefault(require('gulp-stylelint'));
var plumber = _interopDefault(require('gulp-plumber'));
var through = _interopDefault(require('through2'));
var gutil = _interopDefault(require('gulp-util'));
var prettier = _interopDefault(require('prettier'));
var formatter = _interopDefault(require('stylelint-formatter-pretty'));
var eslint = _interopDefault(require('gulp-eslint'));

const execSync = spawn.sync;

function getGitFiles(regexp) {
  var gitFiles = execSync("git", ["ls-files"], { stdio: "pipe" }).stdout.toString().trim().split("\n");
  return gitFiles.filter(fileName => {
    return regexp.exec(fileName);
  });
}

const PRETTIER_CONFIG = {
  printWidth: 80,
  tabWidth: 2,
  useTabs: false,
  singleQuote: false,
  trailingComma: "none",
  jsxBracketSameLine: true,
  bracketSpacing: true,
  semi: false
};

/* eslint-disable no-console */

gulp.task("clean", () => {
  console.log(execSync("git", ["clean", "--force"], { stdio: "pipe" }).stdout.toString());
});

gulp.task("clean:full", () => {
  console.log(execSync("git", ["clean", "--force", "-x"], { stdio: "pipe" }).stdout.toString());
});

var PluginError = gutil.PluginError;

var prettier$1 = function (options) {

  return through.obj(function (file, encoding, callback) {
    if (file.isNull()) return callback(null, file);
    if (file.isStream()) return callback(new PluginError("gulp-prettier", "Streaming not supported"));

    let data;
    let content = file.contents.toString("utf-8");

    try {
      data = prettier.format(content, options);
    } catch (error) {
      return callback(new PluginError("gulp-prettier", error));
    }

    file.contents = new Buffer(data);
    callback(null, file);
  });
};

const PRETTIER_CSS_CONFIG = Object.assign({}, PRETTIER_CONFIG, { parser: "postcss" });

const SRC_SHEETS = /\.(css|scss|pcss)$/;
const SRC_CONFIG = { base: "." };

gulp.task("lint:css", () => {
  return gulp.src(getGitFiles(SRC_SHEETS), SRC_CONFIG).pipe(stylelint({
    reporters: [{
      formatter,
      console: true
    }]
  }));
});

gulp.task("fix:css", () => {
  return gulp.src(getGitFiles(SRC_SHEETS), SRC_CONFIG).pipe(stylelint({
    fix: true,
    reporters: [{
      formatter,
      console: true
    }]
  })).pipe(gulp.dest("."));
});

gulp.task("pretty:css", () => {
  return gulp.src(getGitFiles(SRC_SHEETS), SRC_CONFIG).pipe(plumber()).pipe(prettier$1(PRETTIER_CSS_CONFIG)).pipe(stylelint({
    fix: true,
    reporters: [{
      formatter,
      console: true
    }]
  })).pipe(gulp.dest("."));
});

const SRC_SCRIPTS = /\.(mjs|js|jsx)$/;
const SRC_CONFIG$1 = { base: "." };

const ESLINT_FORMATTER = require.resolve("eslint-formatter-pretty");

gulp.task("lint:js", () => {
  return gulp.src(getGitFiles(SRC_SCRIPTS), SRC_CONFIG$1).pipe(eslint()).pipe(eslint.format(ESLINT_FORMATTER)).pipe(eslint.failAfterError());
});

gulp.task("fix:js", () => {
  return gulp.src(getGitFiles(SRC_SCRIPTS), SRC_CONFIG$1).pipe(plumber()).pipe(eslint({ fix: true })).pipe(eslint.format(ESLINT_FORMATTER)).pipe(gulp.dest("."));
});

gulp.task("pretty:js", () => {
  return gulp.src(getGitFiles(SRC_SCRIPTS), SRC_CONFIG$1).pipe(plumber()).pipe(prettier$1(PRETTIER_CONFIG)).pipe(eslint({ fix: true })).pipe(eslint.format(ESLINT_FORMATTER)).pipe(gulp.dest("."));
});
//# sourceMappingURL=index.es2015.cjs.js.map
